/* streamfuncs.h: -*- C -*-  Header file for stream functions in Meta-HTML. */

/* Author: Brian J. Fox (bfox@ai.mit.edu) Tue Sep 26 21:50:11 1995.

   This file is part of <Meta-HTML>(tm), a system for the rapid deployment
   of Internet and Intranet applications via the use of the Meta-HTML
   language.

   Copyright (c) 1995, 1996, Brian J. Fox (bfox@ai.mit.edu).
   Copyright (c) 1996, Universal Access Inc. (http://www.ua.com).

   Meta-HTML is free software; you can redistribute it and/or modify
   it under the terms of the UAI Free Software License as published
   by Universal Access Inc.; either version 1, or (at your option) any
   later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   UAI Free Software License for more details.

   You should have received a copy of the UAI Free Software License
   along with this program; if you have not, you may obtain one by
   writing to:

   Universal Access Inc.
   129 El Paseo Court
   Santa Barbara, CA
   93101  */

#if !defined (_STREAMFUNCS_H_)
#define _STREAMFUNCS_H_

#if defined (__cplusplus)
extern "C"
{
#endif

extern int mhtml_stdin_fileno;
extern int mhtml_stdout_fileno;
extern int mhtml_stderr_fileno;
/* Return an alist representing the stream referenced by the first
   positional argument in VARS. */
extern char *mhtml_stream_reference_to_alist (Package *vars);

#if defined (__cplusplus)
}
#endif

#endif /* _STREAMFUNCS_H_ */

